# coding: utf-8

"""
    ESG Data

    The ESG Data API offers a centralized source of ESG data and meta data across multiple vendors. The API retrieves ESG data by asset and issuer from multiple vendors, providing the data in one digestible schema. Retrieve ESG data for selected assets and issuers by providing entity id, provider id, date(s) and measure name. Meta data on ESG data measures can be retrieved by selecting a provider, provider category and unique measure names. Time Series API in alpha version, changes may be made at any time.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date
from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist
from asdk_plugin_analytics.agraph.analytics.data.esg.v1.EsgDataAPI.models.v1_id_type import V1IdType
from asdk_plugin_analytics.agraph.analytics.data.esg.v1.EsgDataAPI.models.v1_provider_measure import V1ProviderMeasure

class V1RetrieveEsgDataAsOfDateRequest(BaseModel):
    """
    The request message for EsgDataAPI.RetrieveEsgDataAsOfDate.
    """
    ids: conlist(StrictStr) = Field(...)
    id_type: Optional[V1IdType] = Field(None, alias="idType")
    as_of_date: date = Field(..., alias="asOfDate")
    provider_measures: conlist(V1ProviderMeasure) = Field(..., alias="providerMeasures")
    issuer_traversal: Optional[StrictBool] = Field(None, alias="issuerTraversal", description="Should parent issuer traversal be done. NOTE: This feature is in ALPHA phase.")
    page_size: Optional[StrictInt] = Field(None, alias="pageSize")
    page_token: Optional[StrictStr] = Field(None, alias="pageToken", description="A page token, received from a previous `RetrieveEsgDataAsOfDateRequest` call. Provide this to retrieve the subsequent page.  When paginating, all other parameters provided to `RetrieveEsgDataAsOfDateRequest` must match the call that provided the page token.")
    ignore_default_issuer_traversal: Optional[StrictBool] = Field(None, alias="ignoreDefaultIssuerTraversal")
    __properties = ["ids", "idType", "asOfDate", "providerMeasures", "issuerTraversal", "pageSize", "pageToken", "ignoreDefaultIssuerTraversal"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1RetrieveEsgDataAsOfDateRequest:
        """Create an instance of V1RetrieveEsgDataAsOfDateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in provider_measures (list)
        _items = []
        if self.provider_measures:
            for _item in self.provider_measures:
                if _item:
                    _items.append(_item.to_dict())
            _dict['providerMeasures'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1RetrieveEsgDataAsOfDateRequest:
        """Create an instance of V1RetrieveEsgDataAsOfDateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1RetrieveEsgDataAsOfDateRequest.parse_obj(obj)

        _obj = V1RetrieveEsgDataAsOfDateRequest.parse_obj({
            "ids": obj.get("ids"),
            "id_type": obj.get("idType"),
            "as_of_date": obj.get("asOfDate"),
            "provider_measures": [V1ProviderMeasure.from_dict(_item) for _item in obj.get("providerMeasures")] if obj.get("providerMeasures") is not None else None,
            "issuer_traversal": obj.get("issuerTraversal"),
            "page_size": obj.get("pageSize"),
            "page_token": obj.get("pageToken"),
            "ignore_default_issuer_traversal": obj.get("ignoreDefaultIssuerTraversal")
        })
        return _obj

